@@ -4,7 +4,7 @@ use warnings;
 use parent qw/Plack::Middleware/;
 use Net::IP::XS;
 use Net::IP::Match::Trie;
-our $VERSION = 0.02;
+our $VERSION = 0.03;
 
 use Plack::Util::Accessor qw( IPFile );
 
@@ -56,6 +56,7 @@ sub call {
     my $env  = shift;
 
     my $ip = _build_real_ip($env)->ip;
+    $env->{MATCH_IP} = $ip;
 
     foreach my $matcher (@{ $self->{IPMatcher} }) {
         my $label = $matcher->match_ip($ip);
@@ -74,7 +75,7 @@ __END__
 
 =head1 NAME
 
-Plack::Middleware::IPMatch - 查找指定 CIDR 所对应的 LABEL 
+Plack::Middleware::IPMatch - 查找指定 IP (CIDR) 所对应的标签 LABEL 
 
 =head1 SYNOPSIS
 
@@ -108,7 +109,9 @@ Plack::Middleware::IPMatch 这个是使用, Net::IP::Match::Trie 来实现的超
   112.122.138.160/27,CNC-AH-AH
   112.122.138.192/26,CNC-AH-AH
 
-=head1 IPMATCH_LABEL Header
+=head1 Header
+
+=head2 IPMATCH_LABEL
 
 默认会在 $env 的哈希中增加 C<IPMATCH_LABEL> 的字段的 Header,  这就是查询的结果
 
@@ -116,6 +119,10 @@ Plack::Middleware::IPMatch 这个是使用, Net::IP::Match::Trie 来实现的超
 
   $env->{IPMATCH_LABEL}
 
+=head2 MATCH_IP
+
+进行 ip 转换时候所使用的 IP 地址, 默认会存到这个 header 中传给应用
+
 
 =head1 AUTHOR
 
